@@ -24,7 +24,7 @@ use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Exif;
 use Image::ExifTool::GPS;
 
-$VERSION = '1.16';
+$VERSION = '1.17';
 
 sub ProcessFLIR($$;$);
 sub ProcessFLIRText($$$);
@@ -165,7 +165,10 @@ my %float8g = ( Format => 'float', PrintConv => 'sprintf("%.8g",$val)' );
     },
     0x2b => {
         Name => 'GPSInfo',
-        SubDirectory => { TagTable => 'Image::ExifTool::FLIR::GPSInfo' },
+        SubDirectory => {
+            TagTable => 'Image::ExifTool::FLIR::GPSInfo',
+            ByteOrder => 'LittleEndian',
+        },
     },
     0x2c => {
         Name => 'MeterLink',
@@ -602,15 +605,111 @@ my %float8g = ( Format => 'float', PrintConv => 'sprintf("%.8g",$val)' );
     7 => { Name => 'PiPY2', Description => 'PiP Y2' },
 );
 
-# FLIR GPS record (ref PH/JD)
+# FLIR GPS record (ref PH/JD/forum9615)
 %Image::ExifTool::FLIR::GPSInfo = (
-    GROUPS => { 0 => 'APP1', 2 => 'Image' },
+    GROUPS => { 0 => 'APP1', 2 => 'Location' },
     PROCESS_PROC => \&Image::ExifTool::ProcessBinaryData,
     FIRST_ENTRY => 0,
+    0x00 => {
+        Name => 'GPSValid',
+        Format => 'int32u',
+        RawConv => '$$self{GPSValid} = $val',
+        PrintConv => { 0 => 'No', 1 => 'Yes' },
+    },
+    0x04 => {
+        Name => 'GPSVersionID',
+        Format => 'undef[4]',
+        RawConv => '$val eq "\0\0\0\0" ? undef : $val',
+        PrintConv => 'join ".", split //, $val',
+    },
+    0x08 => {
+        Name => 'GPSLatitudeRef',
+        Format => 'string[2]',
+        RawConv => 'length($val) ? $val : undef',
+        PrintConv => {
+            N => 'North',
+            S => 'South',
+        },
+    },
+    0x0a => {
+        Name => 'GPSLongitudeRef',
+        Format => 'string[2]',
+        RawConv => 'length($val) ? $val : undef',
+        PrintConv => {
+            E => 'East',
+            W => 'West',
+        },
+    },
+  # 0x0c - 4 unknown bytes
+    0x10 => {
+        Name => 'GPSLatitude',
+        Condition => '$$self{GPSValid}',    # valid only if GPSValid is 1
+        Format => 'double', # (signed)
+        PrintConv => 'Image::ExifTool::GPS::ToDMS($self, $val, 1, "N")',
+    },
+    0x18 => {
+        Name => 'GPSLongitude',
+        Condition => '$$self{GPSValid}',    # valid only if GPSValid is 1
+        Format => 'double', # (signed)
+        PrintConv => 'Image::ExifTool::GPS::ToDMS($self, $val, 1, "E")',
+    },
+    0x20 => {
+        Name => 'GPSAltitude',
+        Condition => '$$self{GPSValid}',    # valid only if GPSValid is 1
+        Format => 'float',
+        # (have seen likely invalid value of -1 when GPSValid is 1)
+        PrintConv => 'sprintf("%.2f m", $val)',
+    },
+  # 0x24 - 28 unknown bytes:
+  # 0x28 - int8u: seen 0,49,51,55,57 (ASCII "1","3","7","9")
+  # 0x29 - int8u: seen 0,48 (ASCII "0")
+    0x40 => {
+        Name => 'GPSDOP',
+        Description => 'GPS Dilution Of Precision',
+        Format => 'float',
+        RawConv => '$val > 0 ? $val : undef', # (have also seen likely invalid value of 1)
+        PrintConv => 'sprintf("%.2f", $val)',
+    },
+    0x44 => {
+        Name => 'GPSSpeedRef',
+        Format => 'string[2]',
+        RawConv => 'length($val) ? $val : undef',
+        PrintConv => {
+            K => 'km/h',
+            M => 'mph',
+            N => 'knots',
+        },
+    },
+    0x46 => {
+        Name => 'GPSTrackRef',
+        Format => 'string[2]',
+        RawConv => 'length($val) ? $val : undef',
+        PrintConv => {
+            M => 'Magnetic North',
+            T => 'True North',
+        },
+    },
+  # 0x48 - int32u: seen 0,77
+    0x4c => {
+        Name => 'GPSSpeed',
+        %float2f,
+        RawConv => '$val < 0 ? undef : $val',
+    },
+    0x50 => {
+        Name => 'GPSTrack',
+        %float2f,
+        RawConv => '$val < 0 ? undef : $val',
+    },
+  # 0x54 - float: seen 0,-1
     0x58 => {
         Name => 'GPSMapDatum',
         Format => 'string[16]',
+        RawConv => 'length($val) ? $val : undef',
     },
+  # 0xa4 - string[6]: seen 000208,081210,020409,000608,010408,020808,091011
+  # 0x78 - double[2]: seen "-1 -1","0 0"
+  # 0x78 - float[2]: seen "-1 -1","0 0"
+  # 0xb2 - string[2]?: seen "5\0"
 );
 
 # humidity meter information
@@ -1494,7 +1593,7 @@ Systems Inc. thermal image files (FFF, FPF and JPEG format).
 
 =head1 AUTHOR
 
-Copyright 2003-2018, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2019, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
